@@ -1,8 +1,8 @@
 library("TreeTools", quietly = TRUE)
 
 test_that("TipInstability() error handling", {
-  expect_error(TipInstability(as.phylo(0:3, 6), dev = 'error'))
-  expect_error(TipInstability(as.phylo(0:3, 6), ave = 'error'))
+  expect_error(TipInstability(as.phylo(0:3, 6), dev = "error"))
+  expect_error(TipInstability(as.phylo(0:3, 6), ave = "error"))
 })
 
 test_that("ColByStability() error handling", {
@@ -11,7 +11,7 @@ test_that("ColByStability() error handling", {
 
 test_that("TipInstability() null output", {
   expect_equal(TipInstability(BalancedTree(4)),
-               setNames(rep(0, 4), paste0('t', 1:4)))
+               setNames(rep(0, 4), paste0("t", 1:4)))
 })
 
 test_that("GraphGeodesic() works", {
@@ -34,7 +34,7 @@ test_that("ColByStability()", {
   trees <- AddTipEverywhere(BalancedTree(8), "Rogue")
   tipCol <- col2rgb(ColByStability(trees[3:6]))
   # plot(consensus(trees[3:6], p = 0.5), tip.col = ColByStability(trees[3:6]))
-  expect_gt(tipCol[1, 'Rogue'], tipCol['red', 't1'])
-  expect_equal(tipCol['t2'], tipCol['t1'])
+  expect_gt(tipCol[1, "Rogue"], tipCol["red", "t1"])
+  expect_equal(tipCol["t2"], tipCol["t1"])
 })
 
